@@ -25,8 +25,6 @@
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include <string.h>
-#include <errno.h>
-#include <stdio.h>
 #include <goffice/goffice.h>
 #include <gnm-plugin.h>
 #include "sheet-style.h"
@@ -981,7 +979,7 @@ sc_func_map_in (GnmConventions const *conv, Workbook *scope,
 	    NULL != (new_name = g_hash_table_lookup (namemap, name)))
 		name = new_name;
 	if (NULL == (f = gnm_func_lookup (name, scope)))
-		f = gnm_func_add_placeholder (scope, name, "", TRUE);
+		f = gnm_func_add_placeholder (scope, name, "");
 	return gnm_expr_new_funcall (f, args);
 }
 
@@ -1040,7 +1038,7 @@ sc_file_open (GOFileOpener const *fo, GOIOContext *io_context,
 		workbook_sheet_delete (state.sheet);
 		go_io_error_info_set (io_context, error);
 	}
-	g_object_unref (G_OBJECT (state.textline));
+	g_object_unref (state.textline);
 	g_iconv_close (state.converter);
 	gnm_conventions_unref (state.convs);
 	g_free (state.last_error);
