@@ -23,10 +23,10 @@ void	 dialog_plugin_manager	(WBCGtk *wbcg);
 void	 dialog_goto_cell	(WBCGtk *wbcg);
 void	 dialog_cell_format	(WBCGtk *wbcg,
 				 FormatDialogPosition_t pageno);
-void	 dialog_cell_format_select_style (WBCGtk *wbcg,
-					  gint pages, GtkWindow *w,
-					  GnmStyle *style,
-					  gpointer closure);
+GtkDialog *dialog_cell_format_select_style (WBCGtk *wbcg,
+					    gint pages, GtkWindow *w,
+					    GnmStyle *style,
+					    gpointer closure);
 void	 dialog_cell_format_cond (WBCGtk *wbcg);
 void     dialog_cell_format_style_added (gpointer closure, GnmStyle *style);
 void	 dialog_paste_special	(WBCGtk *wbcg);
