@@ -172,7 +172,7 @@ plugin_service_function_group_func_desc_load (GnmFunc const *fn_def,
 }
 
 static void
-plugin_service_function_group_func_ref_notify  (GnmFunc *fn_def, int refcount)
+plugin_service_function_group_func_ref_notify (GnmFunc *fn_def, int refcount)
 {
 	GOPluginService *service;
 
@@ -185,6 +185,17 @@ plugin_service_function_group_func_ref_notify  (GnmFunc *fn_def, int refcount)
 	}
 }
 
+static void
+delayed_ref_notify (GOPlugin *plugin, GnmFunc *fd)
+{
+	g_signal_handlers_disconnect_by_func (plugin,
+					      G_CALLBACK (delayed_ref_notify),
+					      fd);
+
+	/* We cannot do this until after the plugin has been activated.  */
+	plugin_service_function_group_func_ref_notify (fd, 1);
+}
+
 static void
 plugin_service_function_group_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
@@ -194,14 +205,35 @@ plugin_service_function_group_activate (GOPluginService *service, GOErrorInfo **
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	sfg->func_group = gnm_func_group_fetch (sfg->category_name,
 						sfg->translated_category_name);
-	GO_SLIST_FOREACH (sfg->function_name_list, char, fname,
-		GnmFunc *fn_def;
+	if (gnm_debug_flag ("plugin-func"))
+		g_printerr ("Activating group %s\n", sfg->category_name);
+	GO_SLIST_FOREACH
+		(sfg->function_name_list, char, fname,
+		 GnmFunc *fd;
 
-		fn_def = gnm_func_add_stub (
-			sfg->func_group, fname, sfg->textdomain,
-			plugin_service_function_group_func_desc_load,
-			plugin_service_function_group_func_ref_notify);
-		gnm_func_set_user_data (fn_def, service);
+		 fd = gnm_func_lookup (fname, NULL);
+		 if (fd) {
+#if 0
+			 g_printerr ("Reusing placeholder for %s\n", fname);
+#endif
+		 } else {
+			 fd = gnm_func_add_placeholder (NULL, fname, "?");
+		 }
+		 if (fd->flags & GNM_FUNC_IS_PLACEHOLDER) {
+			 gnm_func_set_user_data (fd, service);
+			 gnm_func_upgrade_placeholder
+				 (fd, sfg->func_group,
+				  sfg->textdomain,
+				  plugin_service_function_group_func_desc_load,
+				  plugin_service_function_group_func_ref_notify);
+			 if (fd->usage_count > 0)
+				 g_signal_connect (go_plugin_service_get_plugin (service),
+						   "state_changed",
+						   G_CALLBACK (delayed_ref_notify),
+						   fd);
+		 } else {
+			 g_warning ("Multiple definitions of function %s -- this cannot be good!", fname);
+		 }
 	);
 	service->is_active = TRUE;
 }
@@ -211,6 +243,9 @@ plugin_service_function_group_deactivate (GOPluginService *service, GOErrorInfo
 {
 	PluginServiceFunctionGroup *sfg = GNM_PLUGIN_SERVICE_FUNCTION_GROUP (service);
 
+	if (gnm_debug_flag ("plugin-func"))
+		g_printerr ("Deactivating group %s\n", sfg->category_name);
+
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	GO_SLIST_FOREACH (sfg->function_name_list, char, fname,
 		gnm_func_free (gnm_func_lookup (fname, NULL));
@@ -356,7 +391,7 @@ plugin_service_ui_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo
 			    strcmp (CXML2C (ptr->name), "action"))
 				continue;
 			name  = go_xml_node_get_cstr (ptr, "name");
-//			label = go_xml_node_get_cstr (ptr, "label");
+/*			label = go_xml_node_get_cstr (ptr, "label");*/
 /*****************************************************************************************/
 			label_node = go_xml_get_child_by_name_no_lang (ptr, "label");
 			label = label_node
@@ -639,14 +674,9 @@ static void
 plugin_service_solver_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	PluginServiceSolver *ssol = GNM_PLUGIN_SERVICE_SOLVER (service);
-	char const *textdomain;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
-
-	textdomain = go_plugin_get_textdomain (service->plugin);
-
 	gnm_solver_db_register (ssol->factory);
-
 	service->is_active = TRUE;
 }
 
