@@ -56,6 +56,7 @@ gnm_float bessel_k (gnm_float x, gnm_float alpha, gnm_float expo);
 /* The normal distribution.  */
 gnm_float dnorm (gnm_float x, gnm_float mu, gnm_float sigma, gboolean give_log);
 gnm_float pnorm (gnm_float x, gnm_float mu, gnm_float sigma, gboolean lower_tail, gboolean log_p);
+gnm_float pnorm2 (gnm_float x1, gnm_float x2);
 gnm_float qnorm (gnm_float p, gnm_float mu, gnm_float sigma, gboolean lower_tail, gboolean log_p);
 
 /* The log-normal distribution.  */
@@ -132,6 +133,11 @@ gnm_float pcauchy (gnm_float x, gnm_float location, gnm_float scale, gboolean lo
 gnm_float random_exppow_pdf     (gnm_float x, gnm_float a, gnm_float b);
 gnm_float random_laplace_pdf    (gnm_float x, gnm_float a);
 
+/* Studentized range distribution */
+/* Note: argument order differs from R.  */
+gnm_float ptukey(gnm_float x, gnm_float nmeans, gnm_float df, gnm_float nranges, gboolean lower_tail, gboolean log_p);
+gnm_float qtukey(gnm_float p, gnm_float nmeans, gnm_float df, gnm_float nranges, gboolean lower_tail, gboolean log_p);
+
 /* ------------------------------------------------------------------------- */
 
 typedef gnm_float (*GnmPFunc) (gnm_float x, const gnm_float shape[],
